@@ -1,6 +1,6 @@
 /******************************************************************************\
- * $Id: overview.cpp,v 1.6 2001/05/24 05:09:21 blais Exp $
- * $Date: 2001/05/24 05:09:21 $
+ * $Id: overview.cpp,v 1.8 2001/06/04 01:23:53 blais Exp $
+ * $Date: 2001/06/04 01:23:53 $
  *
  * Copyright (C) 1999-2001  Martin Blais <blais@iro.umontreal.ca>
  *
@@ -210,8 +210,8 @@ void XxOverview::drawContents( QPainter* pp )
             int ddy = yend - prevy[ii] + 1;
 
             const XxLine& line = diffs->getLine( start );
-            XxResources::Resource dtype =
-               resources->getLineColorType( line, ii, false );
+            XxResources::Resource dtype, dtypeSup;
+            resources->getLineColorType( line, ii, dtype, dtypeSup );
 
             resources->getRegionColor( dtype, back, fore );
             brush.setColor( back );
