@@ -1,6 +1,6 @@
 /******************************************************************************\
- * $Id: text.h,v 1.3 2001/05/22 07:30:19 blais Exp $
- * $Date: 2001/05/22 07:30:19 $
+ * $Id: text.h,v 1.4 2001/05/31 05:51:54 blais Exp $
+ * $Date: 2001/05/31 05:51:54 $
  *
  * Copyright (C) 1999-2001  Martin Blais <blais@iro.umontreal.ca>
  *
@@ -88,6 +88,15 @@ public:
    // Returns the width of pixels that can display text.
    uint getDisplayWidth() const;
 
+   /*----- static member functions -----*/
+
+   static std::string formatClipboardLine(
+      const std::string& clipboardFormat,
+      const XxFno        fileno,
+      const XxFln        lineno,
+      const std::string& filename,
+      const std::string& lineContents
+   );
 
 protected:
 
